package org.apache.commons.lang3.function;

import java.lang.Throwable;
import java.util.Objects;

@FunctionalInterface
/* loaded from: org_apache_commons_lang3_function.jar:org/apache/commons/lang3/function/FailableDoublePredicate.class */
public interface FailableDoublePredicate<E extends Throwable> {
    public static final FailableDoublePredicate FALSE = t -> {
        return false;
    };
    public static final FailableDoublePredicate TRUE = t -> {
        return true;
    };

    boolean test(double d) throws Throwable;

    static <E extends Throwable> FailableDoublePredicate<E> falsePredicate() {
        return FALSE;
    }

    static <E extends Throwable> FailableDoublePredicate<E> truePredicate() {
        return TRUE;
    }

    default FailableDoublePredicate<E> and(FailableDoublePredicate<E> other) {
        Objects.requireNonNull(other);
        return t -> {
            return test(t) && other.test(t);
        };
    }

    default FailableDoublePredicate<E> negate() {
        return t -> {
            return !test(t);
        };
    }

    default FailableDoublePredicate<E> or(FailableDoublePredicate<E> other) {
        Objects.requireNonNull(other);
        return t -> {
            return test(t) || other.test(t);
        };
    }
}
